Turned out it was quite slow.
I replaced it with an Intel hand optimized version made for the StrongARM, and replaced the prefetch opcode by a simple load because this opcode was not supported by the arch of the CPU of this console.
50% faster, this is quite significant for such a low-level, already optimized routine, used extensively in many stages of a game engine.
I think that we should never assume that standard implementations are optimal, trust but verify.